/*GPL*START*
 * 
 * Copyright (C) 1998 by Johannes Overmann <overmann@iname.com>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 * *GPL*END*/  

#ifndef _machine_h_
#define _machine_h_

#include "tstring.h"
#include "tarray.h"

const double UNK_LOAD = -1.0;
const double DOWN_LOAD = -2.0;
const int UNK_RAM = -1;
const TString UNK_GROUP = "?";
const TString UNK_ARCH = "?";


struct Machine {
 public: // data
   TArray<double> hist;
   double load1, load2, load3;
   TString name;
   TString group;
   TString arch;
   int ram;
   bool graph;

   // set
   void setLoad(double l1, double l2, double l3) {
      load1=l1; load2=l2; load3=l3;
   }
   
   // cons
   Machine(): load1(UNK_LOAD), load2(UNK_LOAD), load3(UNK_LOAD), group(UNK_GROUP), 
	  arch(UNK_ARCH), ram(UNK_RAM), graph(false) {}
   Machine(const char *name): load1(UNK_LOAD), load2(UNK_LOAD), load3(UNK_LOAD), 
     name(name), group(UNK_GROUP), arch(UNK_ARCH), ram(UNK_RAM), graph(false) {}
   
   // misc
   void invalidateData() {
      load1=UNK_LOAD;
      load2=UNK_LOAD;
      load3=UNK_LOAD;
      ram=UNK_RAM;
      group = UNK_GROUP;
      arch = UNK_ARCH;
   }
   
   Machine(const Machine& a): hist(a.hist), load1(a.load1), load2(a.load2), load3(a.load3), 
     name(a.name), group(a.group), arch(a.arch), ram(a.ram), graph(a.graph)  {}
   const Machine& operator=(const Machine& a) {
      hist=a.hist;load1=a.load1;load2=a.load2;load3=a.load3; 
      name=a.name;group=a.group;ram=a.ram;graph=a.graph;
		arch=a.arch;
      return *this;
   }
};


void isort(void *base, size_t nmemb, size_t size,
			  int (*compar)(const void *, const void *));

TString str2machine(const char *p);

   
// compare funcs for qsort
int machcmp_load1(const void *pp1, const void *pp2);
int machcmp_load1_r(const void *pp1, const void *pp2);
int machcmp_load2(const void *pp1, const void *pp2);
int machcmp_load2_r(const void *pp1, const void *pp2);
int machcmp_load3(const void *pp1, const void *pp2);
int machcmp_load3_r(const void *pp1, const void *pp2);
int machcmp_name(const void *pp1, const void *pp2);
int machcmp_name_r(const void *pp1, const void *pp2);
int machcmp_group(const void *pp1, const void *pp2);
int machcmp_group_r(const void *pp1, const void *pp2);
int machcmp_ram(const void *pp1, const void *pp2);
int machcmp_ram_r(const void *pp1, const void *pp2);
int machcmp_arch(const void *pp1, const void *pp2);
int machcmp_arch_r(const void *pp1, const void *pp2);


// define TArray<Machine>

inline TString className(const Machine&) {return "Machine";}
inline void dump(const Machine&) {printf("mach");}
inline void dump(FILE *f, const Machine&) {fprintf(f, "mach");}



#endif
